#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-r86rCWYFgh9MHBGzG9rwj
key:                  haskell-language-server-2.3.0.0-r86rCWYFgh9MHBGzG9rwj
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cc7483b192aeab19cb61396ca19b8e68
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-r86rCWYFgh9MHBGzG9rwj
depends:
    aeson-pretty-0.8.10-4CX5mKtVMfDHxBh4AaJqv5
    async-2.2.6-IB55pRMOICm7lPJ05sVN9d base-4.18.2.1
    base16-bytestring-1.0.2.0-DSxrKsTmVLa6G5QgZxymlm
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-5BEhjJUDbRY5n4GkZJCIw0
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-1gq06OiTdkG7AFSCXWttYR filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-ABi3CuZMdW78QTVBoJtGwZ
    githash-0.1.6.3-1km3YgvgTw5KVY8RjTrz4
    hie-bios-0.12.0-B0aRF4nJwOWK0PGLfSx88C
    hiedb-0.4.3.0-CpGQiEnMvnzDTgQq628ZrL
    hls-alternate-number-format-plugin-2.3.0.0-LiisVabCzz2JzrRDGrbLS5
    hls-cabal-fmt-plugin-2.3.0.0-B8RrICobBeMExp9j5Awb5f
    hls-cabal-plugin-2.3.0.0-CasEQcVRF6o1YqfOJM6n8i
    hls-call-hierarchy-plugin-2.3.0.0-69jG8GLxBv2FWWbFHtu1M8
    hls-change-type-signature-plugin-2.3.0.0-BsNBmgSuzM9F5f6V72Qj3f
    hls-class-plugin-2.3.0.0-6HyWuQht3DICzyHkv0HJkF
    hls-code-range-plugin-2.3.0.0-8ogVb7KCME4FPzf4DISy6
    hls-eval-plugin-2.3.0.0-GP9K9HrNiz2B5iiPSBXvNE
    hls-explicit-fixity-plugin-2.3.0.0-66ifiDhf3JW2xwMYnOuXMg
    hls-explicit-imports-plugin-2.3.0.0-2JOEZf5VAbwdppZ5qOEIT
    hls-explicit-record-fields-plugin-2.3.0.0-1oFC2TiKbRk5SQU9Yv6Hxy
    hls-fourmolu-plugin-2.3.0.0-A3FmLVkB3DZHWFfGrpsz8t
    hls-gadt-plugin-2.3.0.0-LTngDGm7nKV7uDWMdLUmqG
    hls-graph-2.3.0.0-HpLGg0l7xYvEeFSog7qEQs
    hls-hlint-plugin-2.3.0.0-Abmdjbeu1Iv6n59ixeiGgp
    hls-module-name-plugin-2.3.0.0-HC5Ru6VgO3j7vYPyobiI1H
    hls-ormolu-plugin-2.3.0.0-Fmyy3hNd89M54OHZe3dOrP
    hls-overloaded-record-dot-plugin-2.3.0.0-1OYrQYC2zEVLmmPswySQOG
    hls-plugin-api-2.3.0.0-8ov4juJAzGVH8FUkWtxMdw
    hls-pragmas-plugin-2.3.0.0-6YZWS8WHuS9B8CNrQV9HUT
    hls-qualify-imported-names-plugin-2.3.0.0-IbI6fBVsiPh9DlwiCi5T0
    hls-refactor-plugin-2.3.0.0-Fkwl7EWG5EH9E0QMmV0Ggv
    hls-rename-plugin-2.3.0.0-NZ4hAlQBQ1Bq0ZeHEiJGJ
    hls-retrie-plugin-2.3.0.0-5OpCrN6B4cMnXmBJFzWl0
    hls-splice-plugin-2.3.0.0-F7qQbeQHzivFoVcImE2Hto
    hls-stylish-haskell-plugin-2.3.0.0-FRzCfIOrO64AlK8rdNunYf
    lsp-2.2.0.0-G42MvkI8UUDFwGwofUskp3
    optparse-applicative-0.18.1.0-ACOZXD1ji7S90GHMXot2xe
    optparse-simple-0.1.1.4-DZx5QyJSmc7HLB2KIZu31B
    prettyprinter-1.7.1-7RKzVGBzgxT19LUdxVNO6E process-1.6.19.0
    safe-exceptions-0.1.7.4-55TadAijt349fxpbRixfL
    sqlite-simple-0.4.19.0-BVg4bkGPqMT7jHfjWiiQBQ text-2.0.2
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

